@@ -11,10 +11,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -99,6 +99,7 @@ exo_die_g_key_file_save (GKeyFile          *key_file,
   guint        n;
   gboolean     desktop_suffix;
   const gchar *suffix;
+  gchar       *path;
 
   g_return_val_if_fail (G_IS_FILE (base), FALSE);
   g_return_val_if_fail (key_file != NULL, FALSE);
@@ -185,13 +186,21 @@ exo_die_g_key_file_save (GKeyFile          *key_file,
     }
 
   /* write the contents to the file */
-  result = g_file_replace_contents (file, data, length, NULL, FALSE,
-#if GLIB_CHECK_VERSION (2, 20, 0)
-                                    G_FILE_CREATE_REPLACE_DESTINATION,
-#else
-                                    G_FILE_CREATE_NONE,
-#endif
-                                    NULL, NULL, error);
+  if (g_file_is_native (file))
+    {
+      /* for local writes, to make sure the file is written to a tmp
+       * file before the origional desktop file is replaced */
+      path = g_file_get_path (file);
+      result = g_file_set_contents (path, data, length, error);
+      g_free (path);
+    }
+  else
+    {
+      /* for remote writes */
+      result = g_file_replace_contents (file, data, length, NULL, FALSE,
+                                        G_FILE_CREATE_REPLACE_DESTINATION,
+                                        NULL, NULL, error);
+    }
 
   /* cleanup */
   g_free (data);
