@@ -199,7 +199,16 @@ exo_open_launch_desktop_file (const gchar *arg)
 #endif
 }
 
-
+static gchar *
+exo_open_get_path (const gchar *string)
+{
+  gchar *escaped;
+  gchar *uri;
+  escaped = g_uri_escape_string (string, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, TRUE);
+  uri = g_strconcat ("file://", escaped, NULL);
+  g_free (escaped);
+  return uri;
+}
 
 static gchar *
 exo_open_find_scheme (const gchar *string)
@@ -210,7 +219,7 @@ exo_open_find_scheme (const gchar *string)
 
   /* is an absolute path, return file uri */
   if (g_path_is_absolute (string))
-    return g_strconcat ("file://", string, NULL);
+    return exo_open_get_path (string);
 
   /* treat it like a relative path */
   current_dir = g_get_current_dir ();
@@ -220,7 +229,7 @@ exo_open_find_scheme (const gchar *string)
   /* verify that a file of the given name exists */
   if (g_file_test (path, G_FILE_TEST_EXISTS))
     {
-       uri = g_strconcat ("file://", path, NULL);
+       uri = exo_open_get_path (path);
        g_free (path);
        return uri;
     }
@@ -307,7 +316,6 @@ exo_open_uri (const gchar  *uri,
 {
   GFile               *file;
   gchar               *scheme;
-  gchar               *escaped;
   GFileInfo           *file_info;
   gboolean             succeed = FALSE;
   gboolean             retval = FALSE;
@@ -331,15 +339,13 @@ exo_open_uri (const gchar  *uri,
   g_free (scheme);
 #endif
 
-  escaped = g_uri_escape_string (uri, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, TRUE);
-  file = g_file_new_for_uri (escaped);
+  file = g_file_new_for_uri (uri);
   scheme = g_file_get_uri_scheme (file);
 
   /* try to launch common schemes for know preferred applications */
   if (scheme != NULL && exo_open_uri_known_category (uri, scheme, &retval))
     {
       g_free (scheme);
-      g_free (escaped);
       return retval;
     }
 
@@ -356,7 +362,7 @@ exo_open_uri (const gchar  *uri,
           g_debug ("file is directory, use filemanager");
 #endif
           /* directories should go fine with a file manager */
-          retval = exo_open_launch_category ("FileManager", escaped);
+          retval = exo_open_launch_category ("FileManager", uri);
           succeed = TRUE;
         }
       else
@@ -382,7 +388,7 @@ exo_open_uri (const gchar  *uri,
                   if (executable == NULL
                       || strcmp (executable, "exo-open") != 0)
                     {
-                      fake_list.data = (gpointer) escaped;
+                      fake_list.data = (gpointer) uri;
                       fake_list.prev = fake_list.next = NULL;
 
                       /* launch it */
@@ -410,7 +416,7 @@ exo_open_uri (const gchar  *uri,
               /* found scheme, open in file manager */
               if (strcmp (scheme, schemes[i]) == 0)
                 {
-                  retval = succeed = exo_open_launch_category ("FileManager", escaped);
+                  retval = succeed = exo_open_launch_category ("FileManager", uri);
                   break;
                 }
             }
@@ -429,13 +435,12 @@ exo_open_uri (const gchar  *uri,
       /* try ftp uris if the file manager/gio failed to recognize it */
       if (scheme != NULL
           && (strcmp (scheme, "ftp") == 0 || strcmp (scheme, "ftps") == 0))
-        retval = exo_open_launch_category ("WebBrowser", escaped);
+        retval = exo_open_launch_category ("WebBrowser", uri);
       else
-        retval = gtk_show_uri (NULL, escaped, 0, error);
+        retval = gtk_show_uri (NULL, uri, 0, error);
     }
 
   g_free (scheme);
-  g_free (escaped);
 
   if (!retval && error != NULL)
     *error = err;
